pub struct MetricsManager;Implementations
Sourceimpl MetricsManager
impl MetricsManager
pub fn boot_metrics_service(listen_addr: String)
Sourceasync fn metrics(
__arg0: ExtraQuery<Filter>,
__arg1: Extension<Registry>,
) -> impl IntoResponse
async fn metrics( __arg0: ExtraQuery<Filter>, __arg1: Extension<Registry>, ) -> impl IntoResponse
Gather metrics from the global registry and encode them in the Prometheus text format.
The handler accepts the following query parameters to filter metrics. Note that include
and exclude should not be used together.
/metrics(without filter)/metrics?include=foo(include one metric)/metrics?include=foo&include=bar(include multiple metrics)/metrics?exclude=foo&exclude=bar(include all but foo and bar)
One can specify parameters by configuring Prometheus scrape config like below:
- job_name: compute-node
params:
include: ["foo", "bar"]Auto Trait Implementations
impl Freeze for MetricsManager
impl RefUnwindSafe for MetricsManager
impl Send for MetricsManager
impl Sync for MetricsManager
impl Unpin for MetricsManager
impl UnwindSafe for MetricsManager